--
-- Frames.lua
-- For use with: InfoBar
-- (c) tgwaste, All rights reserved
--


-- the main frame
--
function frame_main()
	local f = CreateFrame("Frame", "infobar", UIParent, "GameTooltipTemplate")

	f:SetBackdrop(backdrop(bfile,16))
	f:ClearAllPoints()
	f:SetWidth(120)
	f:SetHeight(120)
	f:SetPoint("CENTER")
	f:EnableMouse(true)
	f:SetMovable(true)
	f:RegisterForDrag("LeftButton")
	f:SetScript("OnDragStart", function(self) self:StartMoving() end)
	f:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)

	local mbar = makebar("mana_statusbar","BOTTOMLEFT",8,10)
	local bbar = makebar("boss_statusbar","BOTTOMLEFT",8,25)
	local fpos = 25 + 15

	local t = mbar:CreateFontString("mana_current", "OVERLAY")
		t:SetFontObject(font)
		t:SetPoint("LEFT",0,0)

	local t = mbar:CreateFontString("mana_percent", "OVERLAY")
		t:SetFontObject(font)
		t:SetPoint("RIGHT",5,0)

	local t = bbar:CreateFontString("boss_title", "OVERLAY")
		t:SetFontObject(font)
		t:SetPoint("LEFT",0,0)

	local t = bbar:CreateFontString("boss_percent", "OVERLAY")
		t:SetFontObject(font)
		t:SetPoint("RIGHT",5,0)

	local tt = {
		"gold_title", "gold_amount", "xp_title", "xp_amount",
		"bank_title", "bank_amount", "mb_title", "mb_amount",
		"date_time", "frame_rate"
	}

	local a = 0
	local h = 8
	local v = fpos
	local p = "BOTTOMLEFT"

	for i=1, #tt do
		local t = f:CreateFontString(tt[i], "OVERLAY")
			t:SetFontObject(font)
			t:SetPoint(p,h,v)

		h = -5
		p = "BOTTOMRIGHT"

		if (a == 1) then
			a = 0
			h = 8
			v = v + 15
			p = "BOTTOMLEFT"
		else
			a = a + 1
		end
	end

	f:Show()
end


-- make a statusbar and return the frame
--
function makebar(title,position,horizontal,vertical)
	local f = CreateFrame("StatusBar", title, infobar)

	f:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
	f:GetStatusBarTexture():SetHorizTile(false)
	f:SetStatusBarColor(0, 100/255, 1)
	f:SetMinMaxValues(0,100)
	f:SetValue(100)
	f:SetWidth(102)
	f:SetHeight(10)
	f:SetPoint(position,horizontal,vertical)

	f.bg = f:CreateTexture(nil, "BACKGROUND")
	f.bg:SetTexture("Interface\\TARGETINGFRAME\\UI-StatusBar")
	f.bg:SetVertexColor(0.0, 0.2, 0.38)
	f.bg:SetAllPoints(true)

	return f
end


-- pet frames
--
function frame_pets()
	local f = CreateFrame("Frame", "petframe", infobar)

	f:SetBackdrop(backdrop(bfile,16))
	f:SetPoint("BOTTOM", 0, -60)
	f:SetWidth(340)
	f:SetHeight(60)

	local n = f:CreateFontString("queueframe", "OVERLAY", "GameFontWhiteSmall")

	n:SetFont(frizq, 12, "OUTLINE")
	n:SetPoint("LEFT", 10, 5)

	f:SetScript("OnMouseUp", function(self, btn)
		if (btn == "LeftButton") then
			if (queue > 0) then
				queue = 0
				C_PetBattles.StopPVPMatchmaking()
			else
				queue = time()
				C_PetBattles.StartPVPMatchmaking()
			end
		end
		if (btn == "RightButton") then
			-- _TODO make right-click heal all pets
			--
		end
	end)

	for i=1, 3 do
		local f = CreateFrame("Frame", "petframe"..i, petframe)

		f:SetBackdrop(backdrop(nil,16))

		if (i == 1) then f:SetPoint("TOPLEFT", 75, -10) end
		if (i == 2) then f:SetPoint("TOP", 27, -10, "CENTER") end
		if (i == 3) then f:SetPoint("TOPRIGHT", -21, -10) end

		f:SetWidth(60)
		f:SetHeight(40)

		f:SetScript("OnMouseUp", function(self, btn)
			if (btn == "LeftButton") then
				local id = C_PetJournal.GetPetLoadOutInfo(i)
				C_PetJournal.SummonPetByID(id)
			end
		end)

		local n = f:CreateTexture("peticon"..i, "LOW")
		n:SetAllPoints(f)
		f.texture = n

		local n = f:CreateFontString("petname"..i, "OVERLAY", "GameFontWhiteSmall")
		n:SetFont(frizq, 12, "OUTLINE")
		n:SetPoint("TOPLEFT", -4, 4)

		local n = f:CreateFontString("petxp"..i, "OVERLAY", "GameFontWhiteSmall")
		n:SetFont(frizq, 12, "OUTLINE")
		n:SetPoint("BOTTOM", 0, 3)

		local f = CreateFrame("Frame", "petborder"..i, petframe)
		f:SetBackdrop(backdrop(nil,20))

		if (i == 1) then f:SetPoint("TOPLEFT", 70, -5) end
		if (i == 2) then f:SetPoint("TOP", 27, -5, "CENTER") end
		if (i == 3) then f:SetPoint("TOPRIGHT", -16, -5) end

		f:SetWidth(70)
		f:SetHeight(50)
	end
end


-- gear frames
--
function frame_gear()
	local f = CreateFrame("Frame", "gearavg", PaperDollItemsFrame)

	f:SetPoint("BOTTOMLEFT", 10, 7)
	f:SetWidth(110)
	f:SetHeight(25)

	local n = f:CreateFontString("gearraretext", "OVERLAY", gearavg)
	n:SetFont(frizq, 12, "OUTLINE")
	n:SetPoint("CENTER")

	for i=1, #gtable do
		local x = 50
		local y = -10
		local p = "TOPLEFT"
		local f = CreateFrame("Frame", "gearframe"..i, gtable[i])

		f:SetBackdrop(backdrop(nil,16))
		f:SetPoint("TOP")
		f:SetWidth(41)
		f:SetHeight(41)

		if (i > 8) then
			x = -50
			p = "TOPRIGHT"
		end

		if (i > 16) then
			p = "TOP"
			x = 0
			y = 25
		end

		local n = f:CreateFontString("gearlevel"..i, "OVERLAY", gtable[i])
		n:SetFont(frizq, 10, "OUTLINE")
		n:SetPoint(p, x, y)

		y = y - 10

		local n = f:CreateFontString("durability"..i, "OVERLAY", gtable[i])
		n:SetFont(frizq, 10, "OUTLINE")
		n:SetPoint(p, x, y)
	end
end


-- fading message frame
--
function frame_fmsg()
	local f = CreateFrame("Frame", "fmsgframe", UIParent)

	f:ClearAllPoints()
	f:SetBackdrop(backdrop(bfile,16))
	f:SetHeight(80)
	f:SetWidth(400)
	f:SetPoint("CENTER", 0, 200);
	f:Hide()

	f:SetScript("OnUpdate", function(self)
		if (mtime < GetTime() - 3) then
			local alpha = f:GetAlpha()
			if (alpha ~= 0) then f:SetAlpha(alpha - .01) end
			if (alpha == 0) then f:Hide() end
		end
	end)

	local n = f:CreateFontString("textframe", "BACKGROUND", "PVPInfoTextFont")
	n:SetAllPoints()

	mtime = 0
end

