--
-- InfoBar.lua
-- For use with: InfoBar
-- (c) tgwaste, All rights reserved
--


-- throw gold/xp/runtime snapshot into chat
--
function snapshot()
	local when = date("%H:%M")
	out(ra .. "-----[|r " .. ye .. "SnapShot|r " .. ga .. when .. "|r " .. ra .. "]-----|r")
	out(ga .. "money:|r " .. money)
	out(ga .. "totxp:|r " .. lb .. comma(totxp) .. "|r")
end


-- throw message to fading text frame
--
function fmsg(msg)
	local f = _G["fmsgframe"]
	local t = _G["textframe"]

	t:SetText(msg);
	f:SetAlpha(1);
	f:Show();

	mtime = GetTime()
end


-- manage money gained
--
function manage_money(msg)
	local g = 0
	local s = 0
	local c = 0

	for word in msg:gmatch("%S+") do
		if (word:match("Gold")) then
			g = last
			gold = gold + last
		end

		if (word:match("Silver")) then
			s = last
			silver = silver + last
		end

		if (word:match("Copper")) then
			c = last
			copper = copper + last
		end

		last = word
	end

	while (copper > 99) do
		silver = silver + 1
		copper = copper - 100
	end

	while (silver > 99) do
		gold = gold + 1
		silver = silver - 100
	end

	money = ye .. gold .. "|r " .. si .. silver .. "|r " .. ra .. copper .. "|r"
end


-- manage stuff relating to instances
--
function manage_instance(event)
	local i, iType = IsInInstance()

	if (event == "UPDATE_INSTANCE_INFO" and i == 1) then
		-- entering instance
		--
		queue = time()
		fmsg("Mana Warn Msgs ON")
		out("Entering Instance " .. ga .. "[" .. iType .. "]|r")
	end

	if (event == "INSTANCE_LOCK_STOP") then
		-- leaving instance
		--
		if (queue > 0) then
     	out("Leaving Instance")
			snapshot()
     	out(ga .. "runtime:|r " .. howlong(queue))
			queue = 0
		end
	end
end


-- update main frame
--
function update_main()
	UpdateAddOnMemoryUsage()

	local x = 0

	for i=1, GetNumAddOns() do
		x = x + GetAddOnMemoryUsage(i)
	end

	if (ibmem == 0) then
		x = GetAddOnMemoryUsage(title)
	end

	local mem = string.format("%.2f", x / 1000)
	local rate = floor(GetFramerate() + 0.5)
	local bank = string.format("%d", GetMoney() / 100 / 100)

	update_mana()

	_G["boss_statusbar"]:SetMinMaxValues(0,100)
	_G["boss_statusbar"]:SetValue(0)

	_G["boss_title"]:SetText("Boss")
	_G["boss_percent"]:SetText("0%")

	_G["xp_title"]:SetText("XP")
	_G["xp_amount"]:SetText(lb .. comma(totxp) .. "|r")

	_G["gold_title"]:SetText("Gold")
	_G["gold_amount"]:SetText(money)

	_G["mb_title"]:SetText("Mem")
	_G["mb_amount"]:SetText(si .. mem .. "|r")

	_G["bank_title"]:SetText("Bank")
	_G["bank_amount"]:SetText(ye .. comma(bank) .. "|r")

	_G["date_time"]:SetText(ra .. date("%b %d %H:%M") .. "|r")
	_G["frame_rate"]:SetText(string.format("%s%d|r", getcolor(rate), rate))
end


-- update pets frame
--
function update_pets()
	if (queue > 0) then
		_G["queueframe"]:SetText(gr .. "Queued\n" .. howlong(queue))
	else
		_G["queueframe"]:SetText(re .. "Not\nQueued|r")
	end

	for i=1, 3 do
		local id = C_PetJournal.GetPetLoadOutInfo(i)
		local _, cName, level, xp, maxXP, _, Name, peticon = C_PetJournal.GetPetInfoByPetID(id);
		local health, max_health, attack, speed, rarity = C_PetJournal.GetPetStats(id)
		local red, green, blue, hex = GetItemQualityColor(rarity-1)
		local xpleft = maxXP - xp

		if cName == nil then
			cName = Name
		end

		_G["peticon"..i]:SetTexture(peticon)
		_G["petname"..i]:SetText(ye .. level .. "|r " .. string.format("%-.6s|r", cName))
		_G["petxp"..i]:SetText(gr .. health .. "|r" .. ga .. "/|r" .. xpleft .. "|r")
    _G["petborder"..i]:SetBackdropBorderColor(red,green,blue,1)
	end
end


-- update gear frames
--
function update_gear()
	local rare = 0
	local all = 0

	_G["gearavg"]:Show()

	for i=1, #gtable do
		_G["gearframe"..i]:Show()
	end

	for i=1, #gtable do
		local id = GetInventoryItemLink("player",gslot[i])
		if id then
			local itemName, _, rarity, itemLevel, _, _, _, _, _, _, _ = GetItemInfo(id)
			local red, green, blue, hex = GetItemQualityColor(rarity)
			local durability, max = GetInventoryItemDurability(gslot[i])

			all = all + 1

			if (rarity > 2) then
				rare = rare + 1
			end

			if (durability ~= nil) then
				if (durability < (max/2)) then
					_G["durability"..i]:SetText(re .. durability .. "|r/" .. max)
				else
					_G["durability"..i]:SetText(durability .. "/" .. max)
				end
			else
				_G["durability"..i]:SetText("-")
			end

			_G["gearlevel"..i]:SetText(lb .. itemLevel .. "|r")
			_G["gearframe"..i]:SetBackdropBorderColor(red,green,blue,1)
		end
	end

	_G["gearraretext"]:SetText("Rare: " .. rare .. "/" .. all)
end


-- update boss health if in battle with one
--
function update_boss()
	local boss = 0

	for i=1, 4 do
		if UnitExists(string.format("boss%d",i)) then
			boss = "boss" .. i
		end
	end

	if (boss == 0) then
		-- not spankin any boss
		return
	end

	local min = UnitHealth(boss)
	local max = UnitHealthMax(boss)
	local per = math.ceil((min/max) * 100)

  _G["boss_statusbar"]:SetMinMaxValues(0,max)
  _G["boss_statusbar"]:SetValue(min)

  _G["boss_title"]:SetText("Boss")
	_G["boss_percent"]:SetText(getcolor(per) .. per .. "%|r")

	sbcolor("boss_statusbar", per)
end


-- update only the players mana info
--
function update_mana()
	local min = UnitMana("player")
	local max = UnitManaMax("player")
	local per = math.ceil((min/max) * 100)
	local msg = wh .. "Mana"

	sbcolor("mana_statusbar", per)
	manawarn(per)

	_G["mana_statusbar"]:SetMinMaxValues(0,max)
	_G["mana_statusbar"]:SetValue(min)

	for i=1, 40 do
		local b, _, _, _, _, _, e = UnitBuff("player", i)
		if (b == "Food" or b == "Drink") then
			if (e - GetTime() > 0) then
				msg = string.format("%sMana (%d)", wh, e - GetTime())
			end
		end
	end

	_G["mana_current"]:SetText(msg .. "|r")
	_G["mana_percent"]:SetText(getcolor(per) .. per .. "%|r")
end


-- update all frame sections
--
function update_frames()
	update_main()
	update_pets()
	update_gear()
	update_boss()

	_G["petframe"]:Hide()
	if (showpet == 1) then
		_G["petframe"]:Show()
	end
end


-- enter world
--
function login()
	manage_money("")
	SetMapToCurrentZone()

	-- get pet data
	--
	TogglePetJournal(2)
	TogglePetJournal(2)

	-- say hello
	--
	out("Loaded " .. title .. "+ v" .. version)
	out("Shift + Left-Click for Options")
end


-- handle registered events
--
function event_handler(self,event,arg1)
	if (event == "ADDON_LOADED" and arg1 == title) then
		login()
	end

	if (event == "CHAT_MSG_MONEY" or event == "PLAYER_MONEY") then
		manage_money(arg1)
	end

	if (event == "QUEST_COMPLETE") then
		copper = copper + GetRewardMoney()
		manage_money("")
	end

	if (event == "CHAT_MSG_COMBAT_XP_GAIN") then
		_, xp = arg1:match("(.-) gain (.-) experience.(.-)$")
		totxp = totxp + xp
	end

	if (event == "WORLD_MAP_UPDATE") then
		tick = tick + 1
		if (tick < 10) then return end
		tick = 0
	end

	if (event == "UPDATE_INSTANCE_INFO" or event == "INSTANCE_LOCK_STOP") then
		manage_instance(event)
	end

	if (event == "PET_BATTLE_CLOSE" or event == "PET_BATTLE_OVER") then
		queue = 0
	end

	if (event:match("UNIT")) then
		update_mana()
		update_boss()
		return
	end

	update_frames()
end


-- main
--
frame_main()
frame_pets()
frame_gear()
frame_fmsg()

local f = _G["infobar"]

for i=1, #events do
	f:RegisterEvent(events[i])
end

f:SetScript("OnMouseUp", function(self, btn)
	local a = IsAltKeyDown()
	local c = IsControlKeyDown()
	local s = IsShiftKeyDown()

	if (btn == "RightButton" and a == nil and c == nil and s == nil) then
		snapshot()
		gold = 0
		silver = 0
		copper = 0
		money = 0
		totxp = 0
	end

	if (btn == "LeftButton" and a == nil and c == nil and s == nil) then
		if (showpet == 0) then
			showpet = 1
		else
			showpet = 0
		end
	end

	if (btn == "LeftButton" and a == 1 and c == nil and s == nil) then
		if (ibmem == 0) then
			ibmem = 1
		else
			ibmem = 0
		end
	end

	if (btn == "LeftButton" and a == nil and c == nil and s == 1) then
		out("Left-Click -- Toggle Pet Window")
		out("Right-Click -- Reset Money/XP")
		out("Middle-Click -- Move Bar to Default Position")
		out("Shift-Left-Click -- Show these options")
		out("Shift-Right-Click -- Toggle Settings Pane")
		out("Alt-Left-Click -- Toggle InfoBar/All Mem Usage")
	end

	if (btn == "RightButton" and a == nil and c == nil and s == 1) then
		fmsg("toggle settings")
	end

	if (btn == "MiddleButton" and a == nil and c == nil and s == nil) then
		f:SetPoint("CENTER")
	end

	update_frames()
end)

f:SetScript("OnEvent", event_handler)
f:Show()
 
