--
-- Utils.lua
-- For use with: InfoBar
-- (c) tgwaste, All rights reserved
--


-- send stuff to chatbox
--
function out(msg)
	DEFAULT_CHAT_FRAME:AddMessage(tag .. " " .. msg)
end


-- say something to public
--
function say(msg)
	SendChatMessage(msg, "SAY")
end


-- say something to party
--
function party(msg)
	SendChatMessage(msg, "PARTY")
end


-- returns a frame backdrop
--
function backdrop(bg_file,edge)
	return {
		bgFile=bg_file,
		edgeFile=efile,
		tile=1,
		tileSize=16,
		edgeSize=edge,
		insets={left=4, right=4, top=4, bottom=4}
	}
end


-- takes seconds and returns Xm Xs
--
function howlong(seconds)
	local s = string.format("%d", time() - seconds)
	local m = string.format("%d", s / 60)

	seconds = s - (m * 60)

	return ye .. m .. ga .. "m|r " .. ye .. seconds .. ga .. "s|r"
end


-- returns an appropriate color for a number
--
function getcolor(percent)
  local color = gr

  if (percent < 90) then color = wh end
  if (percent < 50) then color = ye end
  if (percent < 31) then color = re end

  return color
end


-- sets an appropriate color for a statusbar
--
function sbcolor(title,percent)
  if (percent < 101) then
		if (title:match("mana")) then
			_G[title]:SetStatusBarColor(0,.39,1)
		else
			_G[title]:SetStatusBarColor(0,1,0)
		end
	end

	if (percent < 50) then
		_G[title]:SetStatusBarColor(1,1,0)
	end

	if (percent < 31) then
		_G[title]:SetStatusBarColor(1,0,0)
	end
end


-- mana warning messages
--
function manawarn(percent)
	local m = 0
	local i, iType = IsInInstance()

	if (percent < 30 and warn == 0) then
		warn = 1
		m = "+++ Mana Warning (" .. percent .. "%) +++"
	end

	if (percent < 10 and warn < 2) then
		warn = 2
		m = "+++ Mana Critical (" .. percent .. "%) +++"
	end

	if (percent == 100 and warn > 0) then
		warn = 0
		m = "+++ Mana Full (" .. percent .. "%) +++"
	end

	if (m ~= 0) then
		if i then party(m) else fmsg(m) end
	end
end


-- returns current player coordinates
--
function getcoords()
	local pos = 0
	local x, y = GetPlayerMapPosition("player");

	if (x == 0) then
		pos = "-, -"
	else
		pos = string.format("%0.1f, %0.1f", x*100, y*100)
	end

	return pos
end


-- add commas to a number
--
function comma(no)
	local retval = no

	while true do
		retval, k = string.gsub(retval, "^(-?%d+)(%d%d%d)", '%1,%2')
		if (k == 0) then
			break
		end
	end

	return retval
end

